Module k3s

Available on crate feature k3s only.
K3s (lightweight kubernetes) testcontainer

Structs

K3s
Module to work with K3s inside of tests.
K3sCmd

Constants

KUBE_SECURE_PORT
Port that the Kubernetes part of the container has internally Can be rebound externally via testcontainers::core::ImageExt::with_mapped_port
RANCHER_WEBHOOK_PORT
Port that the Rancher part of the container has internally Can be rebound externally via testcontainers::core::ImageExt::with_mapped_port
TRAEFIK_HTTP
Port that the traefik part of the container has internally Can be rebound externally via testcontainers::core::ImageExt::with_mapped_port