Module surrealdb

Module surrealdb 

Available on crate feature surrealdb only.
surrealdb (mutli model database) testcontainer

Structs

SurrealDb
Module to work with SurrealDB inside of tests. Starts an instance of SurrealDB. This module is based on the official SurrealDB docker image. Default user and password is root, and exposed port is 8000 (SURREALDB_PORT).

Constants

SURREALDB_PORT
Port that the SurrealDB container has internally Can be rebound externally via testcontainers::core::ImageExt::with_mapped_port