Available on crate feature
k3s only.Expand description
K3s (lightweight kubernetes) testcontainer
Structs
Constants
- KUBE_
SECURE_ PORT - Port that the
Kubernetespart of the container has internally Can be rebound externally viatestcontainers::core::ImageExt::with_mapped_port - RANCHER_
WEBHOOK_ PORT - Port that the
Rancherpart of the container has internally Can be rebound externally viatestcontainers::core::ImageExt::with_mapped_port - TRAEFIK_
HTTP - Port that the
traefikpart of the container has internally Can be rebound externally viatestcontainers::core::ImageExt::with_mapped_port